# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"plot_images": "00_visualize.ipynb",
         "show": "00_visualize.ipynb",
         "tensor2imgs": "00_visualize.ipynb",
         "multi_thread": "01_process.ipynb",
         "get_name": "03_utils.ipynb",
         "find_contours": "03_utils.ipynb",
         "download_file_from_google_drive": "03_utils.ipynb",
         "mkdir": "03_utils.ipynb",
         "put_text": "03_utils.ipynb",
         "images_to_video": "03_utils.ipynb",
         "get_paths": "03_utils.ipynb",
         "video_to_images": "03_utils.ipynb",
         "make_mini_coco": "04_debug.ipynb",
         "dpython": "04_debug.ipynb"}

modules = ["visualize.py",
           "process.py",
           "utils.py",
           "debug.py"]

doc_url = "https://anhvth.github.io/avcv/"

git_url = "https://github.com/anhvth/avcv/tree/nbdev-convert/"

def custom_doc_links(name): return None
